@@ -1,6 +1,7 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1996-1999
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2000
+ * http://www.biscom.net/~cade  <cade@biscom.net>  <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
@@ -11,9 +12,11 @@
 
 #include "vfu.h"
 
-  void Classify();
+  void vfu_tool_classify();
 
-  void RenameTools();
+  void vfu_tool_rename();
+  
+  void vfu_tool_seq_rename();
 
 #endif //_VFUTOOLS_H_
 
