@@ -5,20 +5,9 @@
 #include <scroll.h>
 #include "conmenu.h"
 
-#ifndef MAXX
-#define MAXX ConMaxX()
-#endif
-#ifndef MAXY
-#define MAXY ConMaxY()
-#endif
+ConMenuInfo con_default_menu_info;
 
-int ConMenuBorders = 0;
-int ConMenuBoxExitCh = 0;
-
-int ConToggleBoxCN = 48; // normal
-int ConToggleBoxCH = 47; // highlight
-int ConToggleBoxTI = 95; // title
-int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
+int con_toggle_box( int x, int y, const char *title, ToggleEntry* toggles, ConMenuInfo *menu_info  )
 {
   TScrollPos scroll;
   int z;
@@ -44,33 +33,33 @@ int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
   if (h > count) h = count;
   if (h == 0) h = 1;
 
-  if (x + w > MAXX) w = MAXX - x - 1;
-  if (y + h > MAXY-4) h = MAXY - y - 5;
+  if (x + w > con_max_x()) w = con_max_x() - x - 1;
+  if (y + h > con_max_y()-4) h = con_max_y() - y - 5;
 
   String str;
   String str1;
   String hots = "";
   for(z = 0; z < count; z++)
     if (strncmp("--", toggles[z].name, 2))
-      StrAddCh( hots, toggles[z].key );
+      str_add_ch( hots, toggles[z].key );
     else
-      StrAddCh( hots,' ' );
-  ConXY(x,y);
+      str_add_ch( hots,' ' );
+  con_xy(x,y);
   int ch = 0;
 
   str = "";
   str = title;
-  StrPad( str,-w, ConMenuBorders ? '-' : ' ' );
-  if (str.len() > w) StrSLeft(str,w);
-  if (ConMenuBorders)
+  str_pad( str,-w, menu_info->bo ? '-' : ' ' );
+  if (str_len(str) > w) str_sleft(str,w);
+  if (menu_info->bo)
     str = ".-" + str + "-.";
   else
     str = "  " + str + "  ";
-  ConOut(x,y,str,ConToggleBoxTI);
+  con_out(x,y,str,menu_info->ti);
   y++;
 
-  scroll.settype(1);
-  scroll.setwrap(0);
+  scroll.type = 1;
+  scroll.wrap = 1;
   scroll.min = 0;
   scroll.max = count-1;
   scroll.pagesize = h;
@@ -85,7 +74,7 @@ int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
       if (scroll.page+z >= count)
         {
         str = " ~";
-        StrPad( str, -(w+2), ' ');
+        str_pad( str, -(w+2), ' ');
         }
       else
         {
@@ -94,36 +83,36 @@ int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
           {
           str = "";
           str += toggles[scroll.page+z].name;
-          StrPad( str, -w, '-');
+          str_pad( str, -w, '-');
           str += "--";
           }
         else
           {
-          str = " "; StrAddCh( str, toggles[scroll.page+z].key ); str += " ";
+          str = " "; str_add_ch( str, toggles[scroll.page+z].key ); str += " ";
           str += toggles[scroll.page+z].name;
-          StrPad( str, -(w-6), ' ');
+          str_pad( str, -(w-6), ' ');
           str1 = toggles[scroll.page+z].states[*(toggles[scroll.page+z].data)];
-          StrPad( str1, 6, ' '); str1 += " ";
+          str_pad( str1, 6, ' '); str1 += " ";
           str += " " + str1;
           }
         }
-      if (ConMenuBorders)
+      if (menu_info->bo)
         str = "|" + str + "|";
       else
         str = " " + str + " ";
 //      if (str.len() > w) StrSLeft(str,w);
 //      str = " " + str + " ";
-      ConOut( x, y+z, str, ( scroll.page+z != scroll.pos ) ? ConToggleBoxCN : ConToggleBoxCH );
+      con_out( x, y+z, str, ( scroll.page+z != scroll.pos ) ? menu_info->cn : menu_info->ch );
       }
-    if (ConMenuBorders)
+    if (menu_info->bo)
       {
       str = "";
-      StrPad( str, w+2, '-' );
+      str_pad( str, w+2, '-' );
       str = "`" + str + "'";
-      ConOut( x, y+scroll.pagesize, str, ConToggleBoxCN );
+      con_out( x, y+scroll.pagesize, str, menu_info->cn );
       }
-    ch = ConGetch();
-    ConMenuBoxExitCh = ch;
+    ch = con_getch();
+    menu_info->ec = ch;
 
     if ( ch == KEY_UP    ) scroll.up();
     if ( ch == KEY_DOWN  ) scroll.down();
@@ -135,7 +124,7 @@ int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
     if ( ch < 0 || ch > 255 ) continue;
     if ( ch == 27 ) return 0;
     if ( ch == 13 /* && strncmp("--", toggles[scroll.pos].name, 2) */ ) return 1;
-    z = ( ch == ' ' ) ? scroll.pos : z = StrFind( hots, ch );
+    z = ( ch == ' ' ) ? scroll.pos : z = str_find( hots, ch );
     if (z > -1 && strncmp("--", toggles[z].name, 2) )
       {
       int state = *(toggles[z].data) + 1;
@@ -146,12 +135,7 @@ int ConToggleBox( int x, int y, const char *title, ToggleEntry* toggles )
   return -1;
 }
 
-int ConMenuBoxCN = 23; // normal
-int ConMenuBoxCH = 47; // highlight
-int ConMenuBoxTI = 95; // title
-int ConMenuBoxAC = -1; // menu box alternative confirm
-char ConMenuHideMagic[32] = "";
-int ConMenuBox( int x, int y, const char *title, PSZCluster *sc, int hotkeys )
+int con_menu_box( int x, int y, const char *title, PSZCluster *sc, int hotkeys, ConMenuInfo *menu_info  )
 {
   TScrollPos scroll;
   int z;
@@ -167,8 +151,8 @@ int ConMenuBox( int x, int y, const char *title, PSZCluster *sc, int hotkeys )
   if (h > sc->count()) h = sc->count();
   if (h == 0) h = 1;
 
-  if (x + w > MAXX) w = MAXX - x - 1;
-  if (y + h > MAXY-5) h = MAXY - y - 5;
+  if (x + w > con_max_x()) w = con_max_x() - x - 5;
+  if (y + h > con_max_y()-5) h = con_max_y() - y - 5;
 
   String str;
   String hots = "";
@@ -176,28 +160,28 @@ int ConMenuBox( int x, int y, const char *title, PSZCluster *sc, int hotkeys )
     {
     for(z = 0; z < sc->count(); z++)
       if (strncmp("--", sc->get(z), 2))
-        StrAddCh( hots,int((const char*)(sc->get(z))[hotkeys]) );
+        str_add_ch( hots,int((const char*)(sc->get(z))[hotkeys]) );
       else
-        StrAddCh( hots,' ' );
-    StrUpCase(hots);
+        str_add_ch( hots,' ' );
+    str_up(hots);
     }
-  ConXY(x,y);
+  con_xy(x,y);
   int ch = 0;
 
   str = " ";
   str += title;
   str += " ";
-  StrPad( str,-(w), ConMenuBorders ? '-' : ' ' );
-  if (str.len() > w) StrSLeft(str,w);
-  if (ConMenuBorders)
+  str_pad( str,-(w), menu_info->bo ? '-' : ' ' );
+  if (str_len(str) > w) str_sleft(str,w);
+  if (menu_info->bo)
     str = ".-" + str + "-.";
   else
     str = "  " + str + "  ";
-  ConOut(x,y,str,ConMenuBoxTI);
+  con_out(x,y,str,menu_info->ti);
   y++;
 
-  scroll.settype(1);
-  scroll.setwrap(1);
+  scroll.type = 1;
+  scroll.wrap = 1;
   scroll.min = 0; scroll.max = sc->count()-1;
   scroll.pagesize = h;
   scroll.pos = 0; scroll.page = 0;
@@ -209,30 +193,32 @@ int ConMenuBox( int x, int y, const char *title, PSZCluster *sc, int hotkeys )
       {
       str = (scroll.page+z >= sc->count())? "~" : sc->get(scroll.page+z);
 
-      if ( ConMenuHideMagic[0] )
+      if ( menu_info->hide_magic[0] )
         {
-        int i = StrRFind( str, ConMenuHideMagic );
+        int i = str_rfind( str, menu_info->hide_magic );
         if ( i != -1)
-          StrSLeft( str, i );
+          str_sleft( str, i );
         }
-      
-      StrPad( str,-w , (strncmp("--", str, 2) == 0)?'-':' ');
-      if (str.len() > w) StrSLeft(str,w);
-      if (ConMenuBorders)
+ 
+      str_pad( str,-w , (strncmp("--", str, 2) == 0)?'-':' ');
+      if (str_len(str) > w) 
+        // str_sleft(str,w);
+        str_dot_reduce( NULL, str, w );
+      if (menu_info->bo)
         str = "| " + str + " |";
       else
         str = "  " + str + "  ";
-      ConOut( x, y+z, str, ( scroll.page+z != scroll.pos ) ? ConMenuBoxCN : ConMenuBoxCH );
+      con_out( x, y+z, str, ( scroll.page+z != scroll.pos ) ? menu_info->cn : menu_info->ch );
       }
-    if (ConMenuBorders)
+    if (menu_info->bo)
       {
       str = "";
-      StrPad( str, w+2, '-' );
+      str_pad( str, w+2, '-' );
       str = "`" + str + "'";
-      ConOut( x, y+scroll.pagesize, str, ConMenuBoxCN );
+      con_out( x, y+scroll.pagesize, str, menu_info->cn );
       }
-    ch = ConGetch();
-    ConMenuBoxExitCh = ch;
+    ch = con_getch();
+    menu_info->ec = ch;
 
     if ( ch == KEY_UP    ) scroll.up();
     if ( ch == KEY_DOWN  ) scroll.down();
@@ -244,36 +230,93 @@ int ConMenuBox( int x, int y, const char *title, PSZCluster *sc, int hotkeys )
     if ( ch < 0 || ch > 255 ) continue;
     if ( ch == 27 )
       {
-      ConMenuBoxAC = -1;
+      menu_info->ac = 0;
       return -1;
       }
     if ( ch == 13 )
       {
       if (strncmp("--", sc->get(scroll.pos), 2) != 0) // ako e "--" e separator
         {
-        ConMenuBoxExitCh = hots[scroll.pos];
-        ConMenuBoxAC = -1;
+        menu_info->ec = hots[scroll.pos];
+        menu_info->ac = -1;
         return scroll.pos;
         }
       }
-    if ( ConMenuBoxAC > -1 && ch == ConMenuBoxAC )
+    if ( menu_info->ac > -1 && ch == menu_info->ac )
       {
       if (strncmp("--", sc->get(scroll.pos), 2) != 0) // ako e "--" e separator
         {
-        ConMenuBoxExitCh = hots[scroll.pos];
-        ConMenuBoxAC = -2;
+        menu_info->ec = hots[scroll.pos];
+        menu_info->ac = -2;
         return scroll.pos;
         }
       }
-    z = StrFind( hots, toupper(ch) );
+    z = str_find( hots, toupper(ch) );
     if (z > -1)
       {
-      ConMenuBoxExitCh = hots[z];
-      ConMenuBoxAC = -1;
+      menu_info->ec = hots[z];
+      menu_info->ac = -1;
       return z;
       }
     }
-  ConMenuBoxAC = -1;
+  menu_info->ac = -1;
   return -1;
 };
 
+int con_full_psz_box( int x, int y, const char *title, PSZCluster *sc, ConMenuInfo *menu_info )
+{
+  TScrollPos scroll;
+  scroll.type = menu_info->st;
+  scroll.wrap = 0;
+  scroll.min = 0;
+  scroll.max = sc->count()-1;
+  scroll.pagesize = con_max_y() - 3; /* one title and two status */
+  scroll.pos = 0;
+  scroll.page = 0;
+  scroll.gotopos(0);
+
+  char pos_str[32];
+
+  con_xy( 1, 1 );
+  con_puts( title, menu_info->ti );
+  con_ce( menu_info->ti );
+  while(4)
+    {
+    String str;
+    int z;
+    for( z = 0; z < scroll.pagesize; z++ )
+      {
+      if ( scroll.page + z < sc->count() )
+        str = sc->get( scroll.page + z );
+      else
+        str = "~";
+      str_dot_reduce( NULL, str, con_max_x()-1 );
+      con_xy( 1, z + 2 );
+      int c = ( scroll.page + z == scroll.pos ) ? menu_info->ch : menu_info->cn;
+      con_puts( str, c );
+      con_ce( c );
+      }
+    sprintf( pos_str, " %5d of %5d", scroll.pos+1, scroll.max+1 );
+    con_out( con_max_x() - 15, 1, pos_str, menu_info->ti );
+    int ch;
+    switch( (ch = con_getch()) )
+      {
+      case 27 : menu_info->ec = 27; return -1; break;
+      case 13 : menu_info->ec = 13; return scroll.pos; break;
+      case KEY_UP    : scroll.up(); break;
+      case KEY_DOWN  : scroll.down(); break;
+      case KEY_NPAGE : scroll.pagedown(); break;
+      case KEY_PPAGE : scroll.pageup(); break;
+      case KEY_HOME  : scroll.home(); break;
+      case KEY_END   : scroll.end(); break;
+      default: 
+        if ( tolower(ch) == tolower(menu_info->ac) ) 
+          {
+          menu_info->ec = menu_info->ac; 
+          return -2; 
+          }
+          break;
+      }
+    }
+}
+
