@@ -12,14 +12,14 @@
 
 #include "unicon.h"
 #include "vstring.h"
-#include "sets.h"
+#include "clusters.h"
 
-extern CharSet FI_LETTERS;
-extern CharSet FI_DIGITS;
-extern CharSet FI_ALPHANUM;
-extern CharSet FI_REALS;
-extern CharSet FI_USERS;
-extern CharSet FI_MASKS;
+extern BSet FI_LETTERS;
+extern BSet FI_DIGITS;
+extern BSet FI_ALPHANUM;
+extern BSet FI_REALS;
+extern BSet FI_USERS;
+extern BSet FI_MASKS;
 
 extern int EditStrBF; // bakground/foreground
 extern int EditStrFH; // first hit color
