@@ -11,7 +11,7 @@
 #ifndef GETOPT_H
 #define GETOPT_H
 
-/* next line added by <cade@bis.bg> see getopt2.cpp for changes */
+/* next line added by <cade@biscom.net> see getopt2.cpp for changes */
 #define GETOPT(opts) while((optc = getopt2(argc, argv, opts)) != -1)
 
 
@@ -21,18 +21,13 @@ extern int opterr;
 extern int optopt;
 extern int optc;
 
-// added by <cade@biscom.net>
-// if '/' should be used as option char or as root directory?
-// if 0, only `-' is option char (default)
-extern int opt_use_slash;
-
 /*
-  set this to `0' to avoid warning message from getopt when
-  reach unknown option
-*/
+ * set this to `0' to avoid warning message from getopt when
+ * reach unknown option
+ */
 extern int opterr_report;
 
-// name changed to getopt2 to avoid library function mismatch...
+/* name changed to getopt2 to avoid library function mismatch */
 
 int getopt2(int argc, char *argv[], char *optstring);
 
