@@ -120,7 +120,7 @@
 #define	NEXT(p)	(((*((p)+1)&0377)<<8) + (*((p)+2)&0377))
 #define	OPERAND(p)	((p) + 3)
 
-// FORWARDS
+/* FORWARDS */
 
 void regc(char b);
 char *reg(int paren,int *flagp);
@@ -177,10 +177,9 @@ static long regsize;		/* Code size. */
 #define	MAGIC	0234
 
 #ifdef STRCSPN
-STATIC int strcspn(char *s1, char *s2);
+int strcspn(char *s1, char *s2);
 #endif
 
-//
 char* regsubn (regexp *re, int n, char *dest)
 {
   dest[0] = 0;
@@ -193,7 +192,7 @@ char* regsubn (regexp *re, int n, char *dest)
   return dest;
 };
 
-int REX( const char* pattern, const char* string )
+int regmatch( const char* pattern, const char* string )
 {
   regexp *re = regcomp( (char*)pattern );
   if (!re) return 0;
@@ -202,7 +201,23 @@ int REX( const char* pattern, const char* string )
   return res;
 }
 
-//
+int regmatchpos( const char* pattern, const char* string )
+{
+  regexp *re = regcomp( (char*)pattern );
+  if (!re) return -1;
+  int res;
+  if ( regexec( re, (char*)string ) )
+    {
+    res = re->startp[0] - pattern;
+    }
+  else
+    {
+    res = -1;
+    }  
+  free( re );
+  return res;
+}
+
 void regerror (char *msg)
 {
   printf("REGEXP ERROR: %s\n", msg);
@@ -223,7 +238,6 @@ void regerror (char *msg)
  * Beware that the optimization-preparation code in here knows about some
  * of the structure of the compiled regexp.
  */
-//
 regexp *regcomp(const char *exp)
 {
 	register regexp *r;
@@ -309,7 +323,6 @@ regexp *regcomp(const char *exp)
  * is a trifle forced, but the need to tie the tails of the branches to what
  * follows makes it hard to avoid.
  */
-//
 char *reg(int paren,int *flagp) /* Parenthesized? */
 {
 	register char *ret;
@@ -379,7 +392,6 @@ char *reg(int paren,int *flagp) /* Parenthesized? */
  *
  * Implements the concatenation operator.
  */
-//
 char *regbranch(int *flagp)
 {
 	register char *ret;
@@ -417,7 +429,6 @@ char *regbranch(int *flagp)
  * It might seem that this node could be dispensed with entirely, but the
  * endmarker role is not redundant.
  */
-//
 char *regpiece(int *flagp)
 {
 	register char *ret;
@@ -480,7 +491,6 @@ char *regpiece(int *flagp)
  * faster to run.  Backslashed characters are exceptions, each becoming a
  * separate node; the code is simpler that way and it's not worth fixing.
  */
-//
 char *regatom(int *flagp)
 {
 	register char *ret;
@@ -545,13 +555,13 @@ char *regatom(int *flagp)
 	case ')':
 		FAIL("internal urp");	/* Supposed to be caught earlier. */
 		/* NOTREACHED */
-		// break;
+		/* break; */
 	case '?':
 	case '+':
 	case '*':
 		FAIL("?+* follows nothing");
 		/* NOTREACHED */
-		// break;
+		/* break; */
 	case '\\':
 		if (*regparse == '\0')
 			FAIL("trailing \\");
@@ -590,7 +600,6 @@ char *regatom(int *flagp)
 /*
  - regnode - emit a node
  */
-//
 char *regnode(char op)	/* Location. */
 {
 	register char *ret;
@@ -614,7 +623,6 @@ char *regnode(char op)	/* Location. */
 /*
  - regc - emit (if appropriate) a byte of code
  */
-//
 void regc(char b)
 {
 	if (regcode != &regdummy)
@@ -628,7 +636,6 @@ void regc(char b)
  *
  * Means relocating the operand.
  */
-//
 void reginsert(char op,char *opnd)
 {
 	register char *src;
@@ -655,7 +662,6 @@ void reginsert(char op,char *opnd)
 /*
  - regtail - set the next-pointer at the end of a node chain
  */
-//
 void regtail(char *p, char *val)
 {
 	register char *scan;
@@ -685,7 +691,6 @@ void regtail(char *p, char *val)
 /*
  - regoptail - regtail on operand of first argument; nop if operandless
  */
-//
 void regoptail(char *p, char *val)
 {
 	/* "Operandless" and "op != BRANCH" are synonymous in practice. */
@@ -713,13 +718,12 @@ static char **regendp;		/* Ditto for endp. */
 #ifdef DEBUG
 int regnarrate = 0;
 void regdump();
-STATIC char *regprop();
+char *regprop();
 #endif
 
 /*
  - regexec - match a regexp against a string
  */
-//
 int regexec(regexp *prog, const char *string)
 {
 	const char *s;
@@ -778,7 +782,6 @@ int regexec(regexp *prog, const char *string)
 /*
  - regtry - try match at specific point
  */
-//
 int regtry(regexp *prog, const char *string) /* 0 failure, 1 success */
 {
 	register int i;
@@ -813,7 +816,6 @@ int regtry(regexp *prog, const char *string) /* 0 failure, 1 success */
  * need to know whether the rest of the match failed) by a loop instead of
  * by recursion.
  */
-//
 int regmatch(char *prog)		/* 0 failure, 1 success */
 {
 	register char *scan;	/* Current node. */
@@ -901,7 +903,7 @@ int regmatch(char *prog)		/* 0 failure, 1 success */
 					return(0);
 			}
 			/* NOTREACHED */
-			// break;
+			/* break; */
 		case CLOSE+1:
 		case CLOSE+2:
 		case CLOSE+3:
@@ -930,7 +932,7 @@ int regmatch(char *prog)		/* 0 failure, 1 success */
 					return(0);
 			}
 			/* NOTREACHED */
-			// break;
+			/* break; */
 		case BRANCH: {
 				const char *save;
 
@@ -979,16 +981,16 @@ int regmatch(char *prog)		/* 0 failure, 1 success */
 				return(0);
 			}
 			/* NOTREACHED */
-			// break;
+			/* break; */
 		case END:
 			return(1);	/* Success! */
 			/* NOTREACHED */
-			// break;
+			/* break; */
 		default:
 			regerror("memory corruption");
 			return(0);
 			/* NOTREACHED */
-			// break;
+			/* break; */
 		}
 
 		scan = next;
@@ -1005,7 +1007,6 @@ int regmatch(char *prog)		/* 0 failure, 1 success */
 /*
  - regrepeat - repeatedly match something simple, report how many
  */
-//
 int regrepeat(char *p)
 {
 	register int count = 0;
@@ -1050,7 +1051,6 @@ int regrepeat(char *p)
 /*
  - regnext - dig the "next" pointer out of a node
  */
-//
 char *regnext(char *p)
 {
 	register int offset;
@@ -1073,7 +1073,6 @@ char *regnext(char *p)
 /*
  - regdump - dump a regexp onto stdout in vaguely comprehensible form
  */
-//
 void regdump(regexp *r)
 {
 	register char *s;
@@ -1115,7 +1114,6 @@ void regdump(regexp *r)
 /*
  - regprop - printable representation of opcode
  */
-//
 char *regprop(char *op)
 {
 	register char *p;
@@ -1206,7 +1204,6 @@ char *regprop(char *op)
  * of characters not from s2
  */
 
-//
 int strcspn(char *s1, char *s2)
 {
 	register char *scan1;
@@ -1215,7 +1212,7 @@ int strcspn(char *s1, char *s2)
 
 	count = 0;
 	for (scan1 = s1; *scan1 != '\0'; scan1++) {
-		for (scan2 = s2; *scan2 != '\0';)	// ++ moved down.
+		for (scan2 = s2; *scan2 != '\0';)	/* ++ moved down. */
 			if (*scan1 == *scan2++)
 				return(count);
 		count++;
