@@ -19,8 +19,6 @@ typedef struct regexp {
 	char program[1];	/* Unwarranted chumminess with compiler. */
 } regexp;
 
-#define static
-
 regexp *regcomp (const char *exp);
 int regexec     (regexp *prog, const char *string);
 void regsub     (regexp *prog, const char *source, char *dest);
@@ -28,6 +26,11 @@ void regerror   (char *msg);
 
 char* regsubn   (regexp *re, int n, char *dest);
 
-int REX( const char* pattern, const char* string );
+/* regmatch compiles and exec patter against given string */
+int regmatch( const char* pattern, const char* string );
+
+/* regmatchpos compiles and exec patter against given string */
+/* return value is the position of found pattern or -1 if not found */
+int regmatchpos( const char* pattern, const char* string );
 
 #endif /* REGEXP */
