@@ -11,9 +11,9 @@
 
 class TScrollPos
   {
-    int type; // 0 -- standart static, 1 -- extended non static
-    int wrap; // 0 -- none, 1 -- wrap end/begin; NOTE: works only on up/down
-    public:
+  public:
+    int type; // 0 -- standart static, else -- extended non static
+    int wrap; // 0 -- none, else -- wrap end/begin; NOTE: works only on up/down
     int min;
     int max;
     int pos;
@@ -26,16 +26,18 @@ class TScrollPos
 
     void create( int pmin, int pmax, int ppos, int ppage, int ppagesize, int pstep)
           { min = pmin; max = pmax; pos = ppos; page = ppage; pagesize = ppagesize; step = pstep; };
-    void settype( int ptype ) { type = ptype; };
-    int  gettype() { return type; };
-    void setwrap( int wtype ) { wrap = wtype; };
 
     void home();
     void end();
     void up();
     void down();
+
     void pageup();
     void pagedown();
+
+    void ppage() { pageup(); }
+    void npage() { pagedown(); }
+
     void gotopos( int newpos );
   };
 
