@@ -13,12 +13,12 @@
 
 #include <clusters.h>
 #include <vstring.h>
+#include <vstrlib.h>
 #include <fnmatch2.h>
 #include <getopt2.h>
 #include <regexp2.h>
 #include <vsuti.h>
 #include <dlog.h>
-#include <sets.h>
 #include <unicon.h>
 #include <scroll.h>
 #include <form_in.h>
